<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2014 Martin Salles <martin@userlike.com>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/



/**
 * Class that adds the wizard icon.
 *
 * @author	Martin Salles <martin@userlike.com>
 * @package	TYPO3
 * @subpackage	tx_userlike
 */
use \TYPO3\CMS\Core\Utility\GeneralUtility;
use \TYPO3\CMS\Core\Utility\ExtensionManagementUtility;

class tx_userlike_wizicon {

	const KEY = 'userlike';

	/**
	 * Processing the wizard items array
	 *
	 * @param array $wizardItems The wizard items
	 * @return array Modified array with wizard items
	 */
	public function proc(array $wizardItems) {
		$LL = $this->includeLocalLang();

		// Add icons.
		$wizardItems['plugins_tx_' . self::KEY] = array(
			'icon'    		=> ExtensionManagementUtility::extPath(self::KEY) . 'Resources/Public/Icons/ext_icon.gif',
			//'icon'				=> 'EXT:'.self::KEY.'/Resources/Public/Icons/ext_icon.gif',
			'title'				=> $GLOBALS['LANG']->getLLL('userlike_widget_title', $LL),
			'description'	=> $GLOBALS['LANG']->getLLL('userlike_widget_description', $LL),
			'params'			=> '&defVals[tt_content][CType]=list&defVals[tt_content][list_type]=' . self::KEY . '_widget'
		);

		// Return modified array.
		return $wizardItems;
	}

	/**
	 * Reads the [extDir]/locallang.xml and returns the $LOCAL_LANG array found in that file.
	 *
	 * @return array The array with language labels
	 */
	protected function includeLocalLang() {

		$file = ExtensionManagementUtility::extPath(self::KEY) . 'Resources/Private/Language/locallang_be.xml';

		if(method_exists(GeneralUtility, 'readLLXMLfile'))
			return GeneralUtility::readLLXMLfile($file, $GLOBALS['LANG']->lang);
		else if( method_exists(GeneralUtility,'readLLfile'))
			return GeneralUtility::readLLfile($file, $GLOBALS['LANG']->lang);
		else {
			$languageFactory = GeneralUtility::makeInstance('TYPO3\CMS\Core\Localization\LocalizationFactory');
			return $languageFactory->getParsedData($file, $GLOBALS['LANG']->lang);
		}
	}
}

if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/userlike/Resources/Private/Php/class.tx_userlike_wizicon.php'])) {
	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/userlike/Resources/Private/Php/class.tx_userlike_wizicon.php']);
}
